==> istio-model-v1beta1-6.3.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/HeadersHeaderOperationsFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface HeadersHeaderOperationsFluent<A extends HeadersHeaderOperationsFluent<A>> extends Fluent<A>{
  public A addToAdd(String key,String value);
  public A addToAdd(Map<String,String> map);
  public A removeFromAdd(String key);
  public A removeFromAdd(Map<String,String> map);
  public Map<String,String> getAdd();
  public <K,V>A withAdd(Map<String,String> add);
  public Boolean hasAdd();
  public A addToRemove(Integer index,String item);
  public A setToRemove(Integer index,String item);
  public A addToRemove(java.lang.String... items);
  public A addAllToRemove(Collection<String> items);
  public A removeFromRemove(java.lang.String... items);
  public A removeAllFromRemove(Collection<String> items);
  public List<String> getRemove();
  public String getRemove(Integer index);
  public String getFirstRemove();
  public String getLastRemove();
  public String getMatchingRemove(Predicate<String> predicate);
  public Boolean hasMatchingRemove(Predicate<String> predicate);
  public A withRemove(List<String> remove);
  public A withRemove(java.lang.String... remove);
  public Boolean hasRemove();
  public A addToSet(String key,String value);
  public A addToSet(Map<String,String> map);
  public A removeFromSet(String key);
  public A removeFromSet(Map<String,String> map);
  public Map<String,String> getSet();
  public <K,V>A withSet(Map<String,String> set);
  public Boolean hasSet();
  
}

==> istio-model-v1beta1-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1beta1/HeadersHeaderOperationsFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface HeadersHeaderOperationsFluent<A extends HeadersHeaderOperationsFluent<A>> extends Fluent<A>{
  public A addToAdd(String key,String value);
  public A addToAdd(Map<String,String> map);
  public A removeFromAdd(String key);
  public A removeFromAdd(Map<String,String> map);
  public Map<String,String> getAdd();
  public <K,V>A withAdd(Map<String,String> add);
  public Boolean hasAdd();
  public A addToRemove(int index,String item);
  public A setToRemove(int index,String item);
  public A addToRemove(java.lang.String... items);
  public A addAllToRemove(Collection<String> items);
  public A removeFromRemove(java.lang.String... items);
  public A removeAllFromRemove(Collection<String> items);
  public List<String> getRemove();
  public String getRemove(int index);
  public String getFirstRemove();
  public String getLastRemove();
  public String getMatchingRemove(Predicate<String> predicate);
  public Boolean hasMatchingRemove(Predicate<String> predicate);
  public A withRemove(List<String> remove);
  public A withRemove(java.lang.String... remove);
  public Boolean hasRemove();
  public A addToSet(String key,String value);
  public A addToSet(Map<String,String> map);
  public A removeFromSet(String key);
  public A removeFromSet(Map<String,String> map);
  public Map<String,String> getSet();
  public <K,V>A withSet(Map<String,String> set);
  public Boolean hasSet();
  
}
